commands

package
v0.0.0-...-543eb04 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 23, 2021 License: GPL-3.0 Imports: 19 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DispatchCommand

func DispatchCommand(config *models.AppConfig, args []string)

func GetCommands

func GetCommands() map[string]models.Command

func Upload

func Upload(client *http.Client, url string, values map[string]io.Reader, config *models.AppConfig) (err error)

Types

type Add

type Add struct {
	Options *models.Opts
}

Add command when name is specified adds new application to package.

func (Add) CheckRequirements

func (a Add) CheckRequirements() (bool, string)

func (Add) ExecuteCommand

func (a Add) ExecuteCommand(opts *models.Opts, config *models.AppConfig) models.CommandResult

func (Add) GetArguments

func (a Add) GetArguments() []string

type Get

type Get struct {
	Options *models.Opts
}

func (Get) CheckRequirements

func (g Get) CheckRequirements() (bool, string)

func (Get) ExecuteCommand

func (g Get) ExecuteCommand(opts *models.Opts, config *models.AppConfig) models.CommandResult

func (Get) GetArguments

func (g Get) GetArguments() []string

type Help

type Help struct {
}

Help command prints help message

func (Help) CheckRequirements

func (h Help) CheckRequirements() (bool, string)

func (Help) ExecuteCommand

func (h Help) ExecuteCommand(_ *models.Opts, _ *models.AppConfig) models.CommandResult

func (Help) GetArguments

func (h Help) GetArguments() []string

type Init

type Init struct {
	Options *models.Opts
}

Init command initializes new package in given output folder

func (Init) CheckRequirements

func (i Init) CheckRequirements() (bool, string)

func (Init) ExecuteCommand

func (i Init) ExecuteCommand(opts *models.Opts, config *models.AppConfig) models.CommandResult

func (Init) GetArguments

func (i Init) GetArguments() []string

type Install

type Install struct {
	Options *models.Opts
}

func (Install) CheckRequirements

func (i Install) CheckRequirements() (bool, string)

func (Install) ExecuteCommand

func (i Install) ExecuteCommand(opts *models.Opts, config *models.AppConfig) models.CommandResult

func (Install) GetArguments

func (i Install) GetArguments() []string

type List

type List struct {
	Options *models.Opts
}

func (List) CheckRequirements

func (l List) CheckRequirements() (bool, string)

func (List) ExecuteCommand

func (l List) ExecuteCommand(opts *models.Opts, config *models.AppConfig) models.CommandResult

func (List) GetArguments

func (l List) GetArguments() []string

type Login

type Login struct {
	Options *models.Opts
}

Login command signs user in and saves token

func (Login) CheckRequirements

func (l Login) CheckRequirements() (bool, string)

func (Login) ExecuteCommand

func (l Login) ExecuteCommand(_ *models.Opts, config *models.AppConfig) models.CommandResult

func (Login) GetArguments

func (l Login) GetArguments() []string

type Pack

type Pack struct {
	Options *models.Opts
}

func (Pack) CheckRequirements

func (p Pack) CheckRequirements() (bool, string)

func (Pack) ExecuteCommand

func (p Pack) ExecuteCommand(opts *models.Opts, config *models.AppConfig) models.CommandResult

func (Pack) GetArguments

func (p Pack) GetArguments() []string

type Push

type Push struct {
	Options *models.Opts
}

Push command pushes package to already added registry Registries can be added using `dots-cli remote add` command

func (Push) CheckRequirements

func (p Push) CheckRequirements() (bool, string)

func (Push) ExecuteCommand

func (p Push) ExecuteCommand(opts *models.Opts, config *models.AppConfig) models.CommandResult

func (Push) GetArguments

func (p Push) GetArguments() []string

type Remote

type Remote struct {
	Options *models.Opts
}

Remote command adds/removes registries for package in current folder

func (Remote) AddRemote

func (r Remote) AddRemote(manifest *models.Manifest) models.CommandResult

func (Remote) CheckRequirements

func (r Remote) CheckRequirements() (bool, string)

func (Remote) ExecuteCommand

func (r Remote) ExecuteCommand(opts *models.Opts, config *models.AppConfig) models.CommandResult

func (Remote) GetArguments

func (r Remote) GetArguments() []string

func (Remote) RemoveRemote

func (r Remote) RemoveRemote(manifest *models.Manifest) models.CommandResult

type Remove

type Remove struct {
	Options *models.Opts
}

func (Remove) CheckRequirements

func (r Remove) CheckRequirements() (bool, string)

func (Remove) ExecuteCommand

func (r Remove) ExecuteCommand(opts *models.Opts, _ *models.AppConfig) models.CommandResult

func (Remove) GetArguments

func (r Remove) GetArguments() []string

type Uninstall

type Uninstall struct {
	Options *models.Opts
}

func (Uninstall) CheckRequirements

func (u Uninstall) CheckRequirements() (bool, string)

func (Uninstall) ExecuteCommand

func (u Uninstall) ExecuteCommand(opts *models.Opts, config *models.AppConfig) models.CommandResult

func (Uninstall) GetArguments

func (u Uninstall) GetArguments() []string

type UpdateDb

type UpdateDb struct {
	Options *models.Opts
}

func (UpdateDb) CheckRequirements

func (u UpdateDb) CheckRequirements() (bool, string)

func (UpdateDb) ExecuteCommand

func (u UpdateDb) ExecuteCommand(_ *models.Opts, config *models.AppConfig) models.CommandResult

func (UpdateDb) GetArguments

func (u UpdateDb) GetArguments() []string

Jump to