Documentation
¶
Index ¶
- func DispatchCommand(config *models.AppConfig, args []string)
- func GetCommands() map[string]models.Command
- func Upload(client *http.Client, url string, values map[string]io.Reader, ...) (err error)
- type Add
- type Get
- type Help
- type Init
- type Install
- type List
- type Login
- type Pack
- type Push
- type Remote
- func (r Remote) AddRemote(manifest *models.Manifest) models.CommandResult
- func (r Remote) CheckRequirements() (bool, string)
- func (r Remote) ExecuteCommand(opts *models.Opts, config *models.AppConfig) models.CommandResult
- func (r Remote) GetArguments() []string
- func (r Remote) RemoveRemote(manifest *models.Manifest) models.CommandResult
- type Remove
- type Uninstall
- type UpdateDb
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DispatchCommand ¶
func GetCommands ¶
Types ¶
type Add ¶
Add command when name is specified adds new application to package.
func (Add) CheckRequirements ¶
func (Add) ExecuteCommand ¶
func (Add) GetArguments ¶
type Help ¶
type Help struct {
}
Help command prints help message
func (Help) CheckRequirements ¶
func (Help) ExecuteCommand ¶
func (Help) GetArguments ¶
type Init ¶
Init command initializes new package in given output folder
func (Init) CheckRequirements ¶
func (Init) ExecuteCommand ¶
func (Init) GetArguments ¶
type Install ¶
func (Install) CheckRequirements ¶
func (Install) ExecuteCommand ¶
func (Install) GetArguments ¶
type Login ¶
Login command signs user in and saves token
func (Login) CheckRequirements ¶
func (Login) ExecuteCommand ¶
func (Login) GetArguments ¶
type Push ¶
Push command pushes package to already added registry Registries can be added using `dots-cli remote add` command
func (Push) CheckRequirements ¶
func (Push) ExecuteCommand ¶
func (Push) GetArguments ¶
type Remote ¶
Remote command adds/removes registries for package in current folder
func (Remote) CheckRequirements ¶
func (Remote) ExecuteCommand ¶
func (Remote) GetArguments ¶
func (Remote) RemoveRemote ¶
func (r Remote) RemoveRemote(manifest *models.Manifest) models.CommandResult
type Remove ¶
func (Remove) CheckRequirements ¶
func (Remove) ExecuteCommand ¶
func (Remove) GetArguments ¶
type Uninstall ¶
func (Uninstall) CheckRequirements ¶
func (Uninstall) ExecuteCommand ¶
func (Uninstall) GetArguments ¶
type UpdateDb ¶
func (UpdateDb) CheckRequirements ¶
func (UpdateDb) ExecuteCommand ¶
func (UpdateDb) GetArguments ¶
Click to show internal directories.
Click to hide internal directories.